/**
 * Copyright (C) 2009 Future Invent Informationsmanagement GmbH. All rights
 * reserved. <http://www.fuin.org/>
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 3 of the License, or (at your option) any
 * later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
package org.fuin.examples.apps4swing;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.Arrays;

import javax.swing.JFrame;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Example login controller implementation.
 */
public class LoginControllerImpl implements LoginController {

	private static final Logger LOG = LoggerFactory.getLogger(LoginControllerImpl.class);

	private JFrame frame;

	private LoginView view;

	/**
	 * Constructor with frame.
	 * 
	 * @param frame
	 *            Frame.
	 */
	public LoginControllerImpl(final JFrame frame) {
		super();
		this.frame = frame;
		this.frame.addWindowListener(new WindowAdapter() {
			@Override
			public void windowClosing(final WindowEvent e) {
				cancel();
			}
		});

	}

	/**
	 * Current thread sleeps for some time.
	 * 
	 * @param millis
	 *            Milliseconds.
	 */
	private void sleep(final long millis) {
		try {
			Thread.sleep(millis);
		} catch (InterruptedException e) {
			e.printStackTrace();
		}
	}

	/**
	 * Checks if the password is "test".
	 * 
	 * @param input
	 *            Password to check.
	 * 
	 * @return If the password was "test" <code>true</code> else
	 *         <code>false</code>.
	 */
	private boolean isPasswordCorrect(final char[] input) {

		// Simulate long user/pw check
		sleep(5000);

		boolean isCorrect = true;
		final char[] correctPassword = { 't', 'e', 's', 't' };

		if (input.length != correctPassword.length) {
			isCorrect = false;
		} else {
			isCorrect = Arrays.equals(input, correctPassword);
		}
		// Zero out the password.
		Arrays.fill(correctPassword, '0');
		return isCorrect;
	}

	/**
	 * Sets the view.
	 * 
	 * @param view
	 *            View.
	 */
	public final void setView(final LoginView view) {
		this.view = view;
		this.view.setUsername("test");
		this.view.setMessage("");
	}

	/**
	 * {@inheritDoc}
	 */
	public final void cancel() {
		LOG.info("CANCEL");
		System.exit(1);
	}

	/**
	 * {@inheritDoc}
	 */
	public final void login(final String username, final char[] password) {
		LOG.info("LOGIN USER " + username);

		if (isPasswordCorrect(password)) {
			LOG.info("LOGIN OK!");
			System.exit(0);
		} else {
			final String message = "INVALID USERNAME OR PASSWORD";
			LOG.info(message);
			view.setMessage(message);
		}

	}

}
